@@ -18,6 +18,8 @@ def slurm_rsync_input(filename, *, tempfilename=None, copylinks=True, silentjobl
   if SLURM_JOBID() is not None:
     tmpdir = pathlib.Path(os.environ["TMPDIR"])
     tempfilename = tmpdir/tempfilename
+    if silentrsync is None:
+      silentrsync = tempfilename.exists()
     tempfilename.parent.mkdir(exist_ok=True, parents=True)
     lockfilename = tempfilename.with_suffix(".lock")
     if lockfilename == tempfilename:
@@ -33,7 +35,7 @@ def slurm_rsync_input(filename, *, tempfilename=None, copylinks=True, silentjobl
     return filename
 
 @contextlib.contextmanager
-def slurm_rsync_output(filename, *, tempfilename=None, copylinks=True, silentrsync=None):
+def slurm_rsync_output(filename, *, tempfilename=None, copylinks=True, silentrsync=None, ok_if_not_created=False):
   filename = pathlib.Path(filename)
   if not filename.is_absolute(): raise ValueError(f"filename {filename} has to be an absolute path")
 
@@ -44,8 +46,15 @@ def slurm_rsync_output(filename, *, tempfilename=None, copylinks=True, silentrsy
   if SLURM_JOBID() is not None:
     tmpdir = pathlib.Path(os.environ["TMPDIR"])
     tmpoutput = tmpdir/tempfilename
+    if silentrsync is None:
+      silentrsync = False
     tmpoutput.parent.mkdir(exist_ok=True, parents=True)
     yield tmpoutput
+    if not tmpoutput.exists():
+      if ok_if_not_created:
+        return
+      else:
+        raise FileNotFoundError(f"{tmpoutput} was not created in the with block")
     _rsync(tmpoutput, filename, silent=silentrsync, copylinks=copylinks)
   else:
     yield filename
